# U_2ls

## Installation

We recommend installing the package inside a conda environment.

```bash
conda create -n U_2ls python=3.11
conda activate U_2ls
pip install git+https://github.com/<your-username>/<your-repo>.git
```



![PyPI version](https://img.shields.io/pypi/v/U_2ls.svg)
[![Documentation Status](https://readthedocs.org/projects/U_2ls/badge/?version=latest)](https://U_2ls.readthedocs.io/en/latest/?version=latest)

This project serves to provide basic tools to make manual selections on interactive UMAPs and draw gradients using plotly and ipywidgets

* PyPI package: https://pypi.org/project/U_2ls/
* Free software: MIT License
* Documentation: https://U_2ls.readthedocs.io.

## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyfeldroy/cookiecutter) and the [audreyfeldroy/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage) project template.
